@@ -144,7 +144,8 @@ class WrappedAnswer(JsonableAnswer):
 
     @classmethod
     def _wrap_type(cls, type_: type) -> type:
-        return create_dataclass(_prepare_class_name([type_],  "Wrapped"), [cls], {"done": bool, "result": type_})
+        attribute_key_to_type = {"done": bool, "result": type_} if type_ not  in (None, type[None]) else {"done": bool}
+        return create_dataclass(_prepare_class_name([type_],  "Wrapped"), [cls], attribute_key_to_type)
 
     def __class_getitem__(cls, modifier: Union[HttpStatusCode, ContentType, type]) -> type:
         type_origin = getattr(modifier, '__origin__', None)
