@@ -8,10 +8,10 @@
 #
 import logging
 from asyncio import TimeoutError, Semaphore
-from enum import Enum, unique
+from enum import unique, StrEnum
 from typing import Union, Optional, Any, Mapping
 
-from aiohttp import ClientResponse, ClientSession, BasicAuth, ClientTimeout
+from aiohttp import ClientResponse, ClientSession, BasicAuth, ClientTimeout, hdrs
 from aiohttp.web_exceptions import HTTPBadRequest, HTTPUnauthorized, HTTPForbidden, HTTPNotFound, \
     HTTPUnprocessableEntity, HTTPBadGateway, HTTPServiceUnavailable, HTTPGatewayTimeout, HTTPInternalServerError, \
     HTTPError
@@ -22,13 +22,14 @@ from http_tools.decoder import Decoder
 from http_tools.decoder_register import DecoderRegister
 from http_tools.header_utils import parse_content_type_header
 from http_tools.http_status_codes import HttpStatusCode
+from http_tools.mime_types import ContentType
 
 logger = logging.getLogger(__name__)
 
 
 class HttpClient(AsyncOnStop):
     @unique
-    class Method(str, Enum):
+    class Method(StrEnum):
         GET = 'GET'
         POST = 'POST'
         PUT = 'PUT'
@@ -154,7 +155,8 @@ class HttpClient(AsyncOnStop):
     async def _process_response_payload(self, response: ClientResponse, force_decoder: Decoder = None) -> Any:
         payload = await response.read()
         if payload:
-            content_type, content_type_info = parse_content_type_header(response.headers.get("Content-Type"))
+            content_type_header = response.headers.get(hdrs.CONTENT_TYPE, ContentType.Octet)
+            content_type, content_type_info = parse_content_type_header(content_type_header)
             charset = content_type_info.get('charset')
             if charset:
                 payload = payload.decode(charset)
